@@ -3,6 +3,7 @@ import optparse
 
 import dbus
 import gobject
+import pynotify
 
 import udiskie.device
 
@@ -43,6 +44,13 @@ class AutoMounter:
             except dbus.exceptions.DBusException, dbus_err:
                 self.log.error('failed to mount device %s: %s' % (device,
                                                                   dbus_err))
+                return
+
+            mount_paths = ', '.join(device.mount_paths())
+            pynotify.Notification('Device mounted',
+                                  '%s mounted on %s' % (device.device_file(),
+                                                        mount_paths),
+                                  'drive-removable-media').show()
 
     def mount_present_devices(self):
         """Mount handleable devices that are already present."""
@@ -82,6 +90,8 @@ def cli(args):
         log_level = logging.DEBUG
     logging.basicConfig(level=log_level, format='%(message)s')
 
+    pynotify.init('udiskie.mount')
+
     mounter = AutoMounter()
     mounter.mount_present_devices()
     return gobject.MainLoop().run()
